@@ -13,8 +13,9 @@ import hwrt.utils as utils
 
 def main(model_folder):
     recording = sys.stdin.readline()
-    print(recording)
-    print(utils.evaluate(recording, model_folder))
+    logging.info(recording)
+    logging.info("Start evaluation...")
+    print(utils.evaluate_model(recording, model_folder))
 
 
 def get_parser():
